<?php

namespace Drp\Analytics\Foundation;

use Drp\Analytics\Exceptions\UnableToResolveAnalyticable;
use Illuminate\Contracts\Auth\Authenticatable;
use Illuminate\Support\Facades\Cookie as CookieFacade;
use Symfony\Component\HttpFoundation\Cookie;

class AnalyticableCookie
{
    public static function forUser(Authenticatable $user): Cookie
    {
        return cookie(
            config('analytics.cookie.name'),
            json_encode([
                'id' => $user->id,
                'type' => get_class($user),
            ]),
            config('analytics.cookie.lifetime') ?? config('session.lifetime')
        );
    }

    /**
     * Attempt to get cookie value or throw an error if not found.
     */
    public static function pull(): ?array
    {
        $cookieName = config('analytics.cookie.name');
        $value = request()->cookie($cookieName);

        if ($value === null && CookieFacade::hasQueued($cookieName)) {
            $value = CookieFacade::queued($cookieName)->getValue();
        }

        if ($value === null) {
            UnableToResolveAnalyticable::cookieNotFound($cookieName);
        }

        return json_decode($value, true);
    }
}
